%--------------------------------------------------------------------------
% Copyright (c) 2014, Florian Heese
% Institute of Communication Systems and Data Processing
% RWTH Aachen University, Germany
% Contact information: heese@ind.rwth-aachen.de
%
% All rights reserved.
%
% Redistribution and use in source and binary forms, with or without
% modification, are permitted provided that the following conditions are
% met:
%
%    * Redistributions of source code must retain the above copyright
%      notice, this list of conditions and the following disclaimer.
%    * Redistributions in binary form must reproduce the above copyright
%      notice, this list of conditions and the following disclaimer in
%      the documentation and/or other materials provided with the 
%      distribution
%    * Neither the name of the RWTH Aachen University nor the names
%      of its contributors may be used to endorse or promote products 
%      derived from this software without specific prior written 
%      permission.
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
% "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
% LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A 
% PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
% OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
% EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
% PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
% PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
% LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
% NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
% SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
%--------------------------------------------------------------------------
function t_rt = rt60(this, channel, bound_start, bound_end, plot_it)
   
    if ~exist('channel', 'var')
        channel = 1;
    end
    
    if ~exist('plot_it', 'var')
        plot_it = 0;
    end
    
    h = this.to_double(:, channel)';
    
    % Generate backwards-integrated Schroeder Decay Curve
    edc = cumsum(h(end:-1:1).^2);
    % Convert curve values to decibel values
    edc_db = 10*log10(abs(edc(end:-1:1)));
    
    % Normalize decay curve to zero
    edc_db = edc_db - max(edc_db);
    
    % create time vector
    t = linspace(0, length(edc)/this.fs, length(edc));
    
    % determin region for least square fitting
    if exist('bound_start', 'var')
        start=find(edc_db <  bound_start, 1);
    else
        start=find(edc_db <  -5, 1);
    end
    if exist('bound_end', 'var')
        finish=find(edc_db < bound_end, 1);
    else
        finish=find(edc_db < -35, 1);
    end
    
    % least square fitting 
    edc_db_region = edc_db(start:finish);
    t_region      = t(start:finish);
    
    coef_p = polyfit(t_region, edc_db_region, 1);
    
    y   = coef_p(1) * (t_region - t(start)) + coef_p(2);
    y_0 = y(1) - coef_p(1) .* t(start);

    % intersection of polyfit line with -60dB
    t_rt = (-60 - y_0) ./ coef_p(1);

    if plot_it
        % EDC
        plot(t, edc_db, 'b', 'Linewidth', 2);
        hold all;
        % fitting line from 0 to -60dB
        t_tmp = linspace(0,t_rt,t_rt*this.fs);
        y = coef_p(1)*t_tmp + coef_p(2);% y_0;
        plot(t_tmp, y, 'g', 'Linewidth', 2)

        % Mark region for least squre fitting
        %plot ([start/this.fs, finish/this.fs], [ih, ih], 'r', 'Linewidth', 2);
        mark_x_start = start/this.fs;
        mark_x_end = finish/this.fs;
        mark_y_base = edc_db(finish)-5;
        plot ([mark_x_start, mark_x_start], [edc_db(start)-5, edc_db(start)+5], 'r', 'Linewidth', 1);
        plot ([mark_x_end, mark_x_end], [edc_db(finish)-5, edc_db(finish)+5], 'r', 'Linewidth', 1);
        %plot ([mark_x_start, mark_x_end], [mark_y_base, mark_y_base]+5, 'r', 'Linewidth', 1);
        
        hold off;
        axis([0 t_rt*2 -90 0])
    end
    
    
    Y=-0.5*coef_p(1);
    rt = 3.*10./Y;
end