% setSignal(newSignal) replaces the signal content. The length and channels 
%   metadata are updated accordingly. newSignal can either be a vector or
%   matrix or a SP.signal object
%
%   signal.setSignal(newSignal);
%--------------------------------------------------------------------------
% Copyright (c) 2014, Florian Heese
% Institute of Communication Systems and Data Processing
% RWTH Aachen University, Germany
% Contact information: heese@ind.rwth-aachen.de
%
% All rights reserved.
%
% Redistribution and use in source and binary forms, with or without
% modification, are permitted provided that the following conditions are
% met:
%
%    * Redistributions of source code must retain the above copyright
%      notice, this list of conditions and the following disclaimer.
%    * Redistributions in binary form must reproduce the above copyright
%      notice, this list of conditions and the following disclaimer in
%      the documentation and/or other materials provided with the 
%      distribution
%    * Neither the name of the RWTH Aachen University nor the names
%      of its contributors may be used to endorse or promote products 
%      derived from this software without specific prior written 
%      permission.
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
% "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
% LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A 
% PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
% OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
% EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
% PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
% PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
% LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
% NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
% SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
%--------------------------------------------------------------------------
function setSignal(this, mySignal )
    
    if isa(mySignal, 'SP.signal')
        mySignal = mySignal.to_double;
    end
   
    if size(mySignal,1) < size(mySignal, 2)
       mySignal =  mySignal';
    end

    if max(abs(mySignal)) <= 1
        this.signalDouble = mySignal;
        this.signalShort  = [];
    else
        this.signalShort = mySignal;
        this.signalDouble = [];
    end
    
    this.signalSamples = size(mySignal, 1);
    this.signalLength  = this.signalSamples ./ this.fs;
    this.channels = size(mySignal, 2);
            
end

